_STACK_SIZE = DEFINED(_STACK_SIZE) ? _STACK_SIZE : 0x2048;
_HEAP_SIZE = DEFINED(_HEAP_SIZE) ? _HEAP_SIZE : 0x2048;

_EL0_STACK_SIZE = DEFINED(_EL0_STACK_SIZE) ? _EL0_STACK_SIZE : 1024;
_EL1_STACK_SIZE = DEFINED(_EL1_STACK_SIZE) ? _EL1_STACK_SIZE : 2048;
_EL2_STACK_SIZE = DEFINED(_EL2_STACK_SIZE) ? _EL2_STACK_SIZE : 1024;

/* Define Memories in the system */
MEMORY {
    SYSRAM (rwx) : ORIGIN = 0xE6300000, LENGTH = 384K
    LPDDR4 (rwx) : ORIGIN = 0x40000000, LENGTH = 2096M
}

/* Specify the default entry point to the program */
ENTRY(_vector_table)

/* Define the sections, and where they are mapped in memory */

SECTIONS
{
.text : {
	. = ALIGN (32);
	KEEP (*(.vectors))
    *(.text)
    *(.text.*)
	*(.gnu.linkonce.t.*)
	. = ALIGN (32);
	__text_end__ = .;   
} > SYSRAM

.data : {
   . = ALIGN(64);
   __data_start = .;
   *(.data)
   *(.data.*)
   *(.gnu.linkonce.d.*)
   __data_end = .;
} > SYSRAM

.bss : {
   . = ALIGN(64);
   __bss_start__ = .;
   *(.bss)
   *(.bss.*)
   *(.gnu.linkonce.b.*)
   . = ALIGN(64);
   __bss_end__ = .;
}  > SYSRAM

.heap (NOLOAD) : {
   . = ALIGN(64);
   _heap = .;
   HeapBase = .;
   _heap_start = .;
   . += _HEAP_SIZE;
   _heap_end = .;
   HeapLimit = .;
} >SYSRAM

.stack (ORIGIN(SYSRAM) + LENGTH(SYSRAM) - 1K)(NOLOAD) : {
   . = ALIGN(64);
   top_of_stacks = . ;
   . = ALIGN(64);
} >SYSRAM

_end = .;
}